### eQuimageLab is a package to postprocess astronomical images with JupyterLab notebooks

Author: Yann-Michel Niquet (https://astro.ymniquet.fr)

### Installation

eQuimageLab is developed in Python 3. To install the latest version of eQuimageLab, open a linux terminal/windows command prompt and run:

  `pip install --user eQuimageLab`

pip will automatically download eQuimageLab and the missing python modules if necessary (dash, plotly, etc...). You can then launch eQuimageLab by typing:

  `eQuimagelab`

in this same terminal. You can also create a link to eQuimageLab from your desktop; an icon is distributed for this purpose with the python package.

### Usage

Preliminary documentation is available at: https://astro.ymniquet.fr/codes/equimagelab/docs/

Dec. 15, 2024: this project is still under heavy development and not yet ready for general use; a more complete documentation with examples will follow soon.

### Known bugs

